LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.std_logic_arith.all;
USE ieee.std_logic_unsigned.all;

ENTITY lights_flash IS
PORT (
SW : IN STD_LOGIC_VECTOR(7 DOWNTO 0);
KEY : IN STD_LOGIC_VECTOR(0 DOWNTO 0);
CLOCK_50 : IN STD_LOGIC;
LEDG : OUT STD_LOGIC_VECTOR(7 DOWNTO 0);
FL_ADDR : OUT STD_LOGIC_VECTOR (21 DOWNTO 0);
FL_DQ : INOUT STD_LOGIC_VECTOR (7 DOWNTO 0);
FL_OE_N : OUT STD_LOGIC;
FL_CE_N : OUT STD_LOGIC;
FL_WE_N : OUT STD_LOGIC;
DRAM_ADDR : OUT STD_LOGIC_VECTOR (11 DOWNTO 0);
DRAM_DQ:INOUT STD_LOGIC_VECTOR (15 DOWNTO 0);
DRAM_BA_0:OUT STD_LOGIC;
DRAM_BA_1:OUT STD_LOGIC;
DRAM_RAS_N:OUT STD_LOGIC;
DRAM_CAS_N: OUT STD_LOGIC;
DRAM_CKE :OUT STD_LOGIC;
DRAM_CLK: IN STD_LOGIC;
DRAM_WE_N:OUT STD_LOGIC;
DRAM_CS_N:OUT STD_LOGIC;
DRAM_LDQM: OUT STD_LOGIC;
DRAM_UDQM: OUT STD_LOGIC
);
END lights_flash;
              
              
  ARCHITECTURE structure of lights_flash IS
  COMPONENT lights_sopc           
   port (
              -- 1) global signals:
                 signal clk : IN STD_LOGIC;
                 signal pll_0_c0_out : OUT STD_LOGIC;
                 signal pll_0_c1_out : OUT STD_LOGIC;
                 signal reset_n : IN STD_LOGIC;

              -- the_LEDs
                 signal out_port_from_the_LEDs : OUT STD_LOGIC_VECTOR (7 DOWNTO 0);

              -- the_pio_0
                 signal in_port_to_the_pio_0 : IN STD_LOGIC_VECTOR (7 DOWNTO 0);

              -- the_pll_0
                 signal locked_from_the_pll_0 : OUT STD_LOGIC;

              -- the_sdram_0
                 signal zs_addr_from_the_sdram_0 : OUT STD_LOGIC_VECTOR (11 DOWNTO 0);
                 signal zs_ba_from_the_sdram_0 : OUT STD_LOGIC_VECTOR (1 DOWNTO 0);
                 signal zs_cas_n_from_the_sdram_0 : OUT STD_LOGIC;
                 signal zs_cke_from_the_sdram_0 : OUT STD_LOGIC;
                 signal zs_cs_n_from_the_sdram_0 : OUT STD_LOGIC;
                 signal zs_dq_to_and_from_the_sdram_0 : INOUT STD_LOGIC_VECTOR (15 DOWNTO 0);
                 signal zs_dqm_from_the_sdram_0 : OUT STD_LOGIC_VECTOR (1 DOWNTO 0);
                 signal zs_ras_n_from_the_sdram_0 : OUT STD_LOGIC;
                 signal zs_we_n_from_the_sdram_0 : OUT STD_LOGIC;

              -- the_tri_state_bridge_0_avalon_slave
                 signal address_to_the_cfi_flash_0 : OUT STD_LOGIC_VECTOR (21 DOWNTO 0);
                 signal data_to_and_from_the_cfi_flash_0 : INOUT STD_LOGIC_VECTOR (7 DOWNTO 0);
                 signal read_n_to_the_cfi_flash_0 : OUT STD_LOGIC;
                 signal select_n_to_the_cfi_flash_0 : OUT STD_LOGIC;
                 signal write_n_to_the_cfi_flash_0 : OUT STD_LOGIC
              );
  END COMPONENT;
  
  BEGIN
  NIOS2: lights_sopc PORT MAP(
  clk=>CLOCK_50,
  reset_n=>KEY(0),
  out_port_from_the_LEDs=>LEDG,
  in_port_to_the_pio_0=>SW,
  zs_addr_from_the_sdram_0=>DRAM_ADDR,
  zs_ba_from_the_sdram_0(0)=>DRAM_BA_0,
  zs_ba_from_the_sdram_0(1)=>DRAM_BA_1,
  zs_cas_n_from_the_sdram_0=>DRAM_CAS_N,
  zs_cke_from_the_sdram_0=>DRAM_CKE,
  zs_cs_n_from_the_sdram_0=>DRAM_CS_N,
  zs_dq_to_and_from_the_sdram_0=>DRAM_DQ,
  zs_dqm_from_the_sdram_0(0)=>DRAM_LDQM,
  zs_dqm_from_the_sdram_0(1)=>DRAM_UDQM,
  zs_ras_n_from_the_sdram_0=>DRAM_RAS_N,
  zs_we_n_from_the_sdram_0=>DRAM_WE_N,
  address_to_the_cfi_flash_0=> FL_ADDR,
  data_to_and_from_the_cfi_flash_0=>FL_DQ,
  read_n_to_the_cfi_flash_0=>FL_OE_N,
  select_n_to_the_cfi_flash_0=>FL_CE_N,
  write_n_to_the_cfi_flash_0=>FL_WE_N
  ) ;
  END structure;           
              
              